==> e107-0.7.20.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum_admin.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/forum/languages/English/lan_forum_admin.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("FORLAN_1", "You must enter the number of days you wish to prune.");
define("FORLAN_2", "Please select to either delete pruned posts completely, or make them inactive (not deleted but not visible in forums)");
define("FORLAN_3", "delete");
define("FORLAN_4", "Make inactive");
define("FORLAN_5", "Carry Out Prune");
define("FORLAN_6", "Cancel");
define("FORLAN_7", "Forum Options");
define("FORLAN_8", "Forums pruned.");
define("FORLAN_9", "Prune not required.");
define("FORLAN_10", "Options Saved");
define("FORLAN_11", "Forum created");
define("FORLAN_12", "Forum updated");
define("FORLAN_13", "Parent created");
define("FORLAN_14", "Forum parent updated");
define("FORLAN_15", "Please tick the confirm box to delete the forum");
define("FORLAN_16", "Forums");
define("FORLAN_17", "No parents yet");
define("FORLAN_18", "Existing Parents");
define("FORLAN_19", "Edit");
define("FORLAN_20", "Delete");
define("FORLAN_21", "tick to confirm");
define("FORLAN_22", "Parent");
define("FORLAN_23", "Viewable by");
define("FORLAN_24", "Indicates who can view the forum");
define("FORLAN_25", "Update Parent");
define("FORLAN_26", "Create Parent");
define("FORLAN_27", "You need to define at least one forum parent before creating a forum.");
define("FORLAN_28", "Forums");
define("FORLAN_29", "No forums yet.");
define("FORLAN_30", "Existing Forums");
define("FORLAN_31", "Name");
define("FORLAN_32", "Description");
define("FORLAN_33", "Moderators");
define("FORLAN_34", "Choose userclass for moderators of this forum");
define("FORLAN_35", "Update Forum");
define("FORLAN_36", "Create Forum");
define("FORLAN_37", "Order");
define("FORLAN_38", "Closed");
define("FORLAN_39", "Members Only");
define("FORLAN_40", "Restricted");
define("FORLAN_41", "move up");
define("FORLAN_42", "move down");
define("FORLAN_43", "Preview / Forum Order");
define("FORLAN_44", "Enclose tables");
define("FORLAN_45", "Tick this to render the forum within theme table");
define("FORLAN_46", "Title displayed in caption if enclose tables is ticked");
define("FORLAN_47", "Enable email notification");
define("FORLAN_48", "Tick this to allow your users to have the option of receiving an email when somebody replies to their post");
define("FORLAN_49", "Enable polls");
define("FORLAN_50", "Tick this to allow your users to set polls in the forums - the Polls plugin must be installed to use this feature");
define("FORLAN_51", "Enable tracking");
define("FORLAN_52", "Tick this to allow your users to track threads and be emailed when the thread is replied to");
define("FORLAN_53", "Email prefix");
define("FORLAN_54", "The text you enter will prefix the subject on any emails sent through the forum");
define("FORLAN_55", "Popular thread threshold");
define("FORLAN_56", "Number of posts made to a thread before it is marked as popular");
define("FORLAN_57", "Posts per page");
define("FORLAN_58", "Number of posts displayed per page");
define("FORLAN_59", "Prune");
define("FORLAN_60", "This will delete all threads that have not received a reply in the number of days you enter. <br /><b>Please be careful using this function!</b>");
define("FORLAN_61", "Update Options");
define("FORLAN_62", "Forum Options");
define("FORLAN_63", "Ranks");
define("FORLAN_64", "Enter your levels here, if left blank generic stars will be used to denote level. Separate levels with comma. Maximum of 10 levels, lowest first.");
define("FORLAN_65", "Forum Title");
define("FORLAN_66", "Poll plugin not installed");

define("FORLAN_70", "Enable file / image attachments");
define("FORLAN_71", "Allow users to upload file or image with their forum post,");
define("FORLAN_72", "Update Order");
define("FORLAN_73", "Order Updated");

define("FORLAN_75", "Parents");
define("FORLAN_76", "Forums Front Page");
define("FORLAN_77", "Create Forums");
define("FORLAN_78", "Forum Order");
define("FORLAN_79", "Preferences");
define("FORLAN_80", "Options");
define("FORLAN_81", "Are you sure you want to delete this parent? - forums of this parent will also be deleted");
define("FORLAN_82", "Are you sure you want to delete this forum?");
define("FORLAN_83", "Create Parents");
define("FORLAN_84", "Members Only");
define("FORLAN_85", "Read Only");
define("FORLAN_86", "Admin Only");
define("FORLAN_87", "Prune topics with no replies in this many days:");

define("FORLAN_88", "Prune topics with no replies in this many days:");

define("FORLAN_89", "Delete posts completely");
define("FORLAN_90", "Make posts inactive");

define("FORLAN_91", "post(s) made inactive");
define("FORLAN_92", "thread(s) deleted");
define("FORLAN_93", "reply (replies) deleted");

define("FORLAN_94", "Set Ranks");
define("FORLAN_95", "Ranks saved");
define("FORLAN_96", "Forum deleted");
define("FORLAN_97", "Parent deleted");

define("FORLAN_98", "Rank Name");
define("FORLAN_99", "number of points before level change");
define("FORLAN_100", "upload images to e107_themes/Your_Theme/forum/");
define("FORLAN_101", "Main Site Admin");
define("FORLAN_102", "Threshold");
define("FORLAN_103", "Site Admin");
define("FORLAN_104", "Rank Image");
define("FORLAN_105", "Forum Moderator");


define("FORLAN_106", "Prune Type:");
define("FORLAN_107", "Forum");
define("FORLAN_108", " deleted");
define("FORLAN_109", "days:");
define("FORLAN_110", "Prune");
define("FORLAN_111", "deactivate");

define("FORLAN_112", "Enable Redirect");
define("FORLAN_113", "Tick this to make browser redirect to forum page after replying");
define("FORLAN_114", "User Custom Title");
define("FORLAN_115", "Tick this to allow users to change their Custom Title");
define("FORLAN_116", "Reported Posts");
define("FORLAN_117", "This will delete the record of the reported post. Not the post itself.");
define("FORLAN_118", "Reported post deleted");
// define("FORLAN_119", "Clicking links will open forum in a new window.");
define("FORLAN_120", "Tick this to allow users to change their Custom Title");
define("FORLAN_121", "No reported posts");
define("FORLAN_122", "Click here to email admin when someone reports a forum post");
define("FORLAN_123", "Forum Rules");
define("WMGLAN_1", "Rules for Guests");
define("WMGLAN_2", "Rules for Members");
define("WMGLAN_3", "Rules for Administrators");
define("WMGLAN_4", "Submit");
define("WMGLAN_5", "Set Forum Rules");
define("WMGLAN_6", "Activate?");
define("FORLAN_126", "Show Tooltips");
define("FORLAN_127", "Tick here to show a tooltip containing the first post of the thread when mouse hovers over thread name. ");
define("FORLAN_128", "Length of tooltip");
define("FORLAN_129", "This will determine the number of characters to display in the tooltip. ");
define("FORLAN_130", "click here");
define("FORLAN_131", "to set max file size, allowed types etc");
define("FORLAN_132", "Emphasize Sticky Threads");
define("FORLAN_133", "Give extra emphasis to sticky threads (separate thread sections and headers)");
define("FORLAN_134", "Maximum width of uploaded image");
define("FORLAN_135", "Leave blank to disable auto resizing of images");
define("FORLAN_136", "Create link to full size image");
define("FORLAN_137", "Enabling this will resize larger images and also create a link to the original full size image. If disabled, original image will be discarded");
define("FORLAN_138", "Prune these forums");
define("FORLAN_139", "To use this setting you also need to tick 'Enable image posting' on the <a href='".e_ADMIN."image.php'>images</a> page");
define("FORLAN_140", "View");
define("FORLAN_141", "Post");
define("FORLAN_142", "Post permission");
define("FORLAN_143", "Indicates who can post to the forum");
define("FORLAN_144", "Moderators set");
define("FORLAN_145", "Configure sub-forums");
define("FORLAN_146", "No sub-forums yet");
define("FORLAN_147", "Update sub-forums");
define("FORLAN_148", "Create sub-forums");
define("FORLAN_149", "sub-forums");
define("FORLAN_150", "sub-forum");
define("FORLAN_151", "ID");
define("FORLAN_152", "posts");
define("FORLAN_153", "Tools");
define("FORLAN_154", "Reply Deleted");
define("FORLAN_155", "Forum Categories");

define("FORLAN_156", "Select forum(s) to perform action on");
define("FORLAN_157", "All Forums");
define("FORLAN_158", "Recalculate forum lastpost info");
define("FORLAN_159", "Select to recalculate lastpost info");
define("FORLAN_160", "Select to perform this on forums only, not threads");
define("FORLAN_161", "Recalculate post / reply counts");
define("FORLAN_162", "Select to recalculate forum thread/reply counts");
define("FORLAN_163", "Recalculate user forum posts counts");
define("FORLAN_164", "Select to recalculate user forum counts");
define("FORLAN_165", "Execute functions");
define("FORLAN_166", "Forum Tools");
define("FORLAN_167", "Counts updated for forum");
define("FORLAN_168", "Lastpost info updated for forum");
define("FORLAN_169", "User forum counts updated");
define("FORLAN_170", "Reports");
define("FORLAN_171", "Report on forum post");
define("FORLAN_172", "Delete This Report");
define("FORLAN_173", "Thread title");
define("FORLAN_174", "Reported by user");
define("FORLAN_175", "Report submitted");
define("FORLAN_176", "Report");

define("FORLAN_177", "email notification ON by default");
define("FORLAN_178", "Tick this to allow make the email notification checkbox be on by default");

define("FORLAN_179", "(Adding a * to the beginning of the forum name will make this forum a container for sub-forums only. The forum theme must support this option also.)");
define("FORLAN_180", "Confirm delete operation");
define("FORLAN_181", "Confirm Delete");
define("FORLAN_182", "also recalculate replies for all threads in selected forum");
define("FORLAN_183", "(this function is not allowed when selecting 'all forums' due to the number of queries it will generate)");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum_admin.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/forum/languages/English/lan_forum_admin.php $
|     $Revision: 12242 $
|     $Id: lan_forum_admin.php 12242 2011-06-02 19:59:08Z e107steved $
|     $Author: e107steved $
+----------------------------------------------------------------------------+
*/
define("FORLAN_1", "You must enter the number of days you wish to prune.");
define("FORLAN_2", "Please select to either delete pruned posts completely, or make them inactive (not deleted but not visible in forums)");
define("FORLAN_3", "delete");
define("FORLAN_4", "Make inactive");
define("FORLAN_5", "Carry Out Prune");
define("FORLAN_6", "Cancel");
define("FORLAN_7", "Forum Options");
define("FORLAN_8", "Forums pruned.");
define("FORLAN_9", "Prune not required.");
define("FORLAN_10", "Options Saved");
define("FORLAN_11", "Forum created");
define("FORLAN_12", "Forum updated");
define("FORLAN_13", "Parent created");
define("FORLAN_14", "Forum parent updated");
define("FORLAN_15", "Please tick the confirm box to delete the forum");
define("FORLAN_16", "Forums");
define("FORLAN_17", "No parents yet");
define("FORLAN_18", "Existing Parents");
define("FORLAN_19", "Edit");
define("FORLAN_20", "Delete");
define("FORLAN_21", "tick to confirm");
define("FORLAN_22", "Parent");
define("FORLAN_23", "Viewable by");
define("FORLAN_24", "Indicates who can view the forum");
define("FORLAN_25", "Update Parent");
define("FORLAN_26", "Create Parent");
define("FORLAN_27", "You need to define at least one forum parent before creating a forum.");
define("FORLAN_28", "Forums");
define("FORLAN_29", "No forums yet.");
define("FORLAN_30", "Existing Forums");
define("FORLAN_31", "Name");
define("FORLAN_32", "Description");
define("FORLAN_33", "Moderators");
define("FORLAN_34", "Choose userclass for moderators of this forum");
define("FORLAN_35", "Update Forum");
define("FORLAN_36", "Create Forum");
define("FORLAN_37", "Order");
define("FORLAN_38", "Closed");
define("FORLAN_39", "Members Only");
define("FORLAN_40", "Restricted");
define("FORLAN_41", "move up");
define("FORLAN_42", "move down");
define("FORLAN_43", "Preview / Forum Order");
define("FORLAN_44", "Enclose tables");
define("FORLAN_45", "Tick this to render the forum within theme table");
define("FORLAN_46", "Title displayed in caption if enclose tables is ticked");
define("FORLAN_47", "Enable email notification");
define("FORLAN_48", "Tick this to allow your users to have the option of receiving an email when somebody replies to their post");
define("FORLAN_49", "Enable polls");
define("FORLAN_50", "Tick this to allow your users to set polls in the forums - the Polls plugin must be installed to use this feature");
define("FORLAN_51", "Enable tracking");
define("FORLAN_52", "Tick this to allow your users to track threads and be emailed when the thread is replied to");
define("FORLAN_53", "Email prefix");
define("FORLAN_54", "The text you enter will prefix the subject on any emails sent through the forum");
define("FORLAN_55", "Popular thread threshold");
define("FORLAN_56", "Number of posts made to a thread before it is marked as popular");
define("FORLAN_57", "Posts per page");
define("FORLAN_58", "Number of posts displayed per page");
define("FORLAN_59", "Prune");
define("FORLAN_60", "This will delete all threads that have not received a reply in the number of days you enter. <br /><b>Please be careful using this function!</b>");
define("FORLAN_61", "Update Options");
define("FORLAN_62", "Forum Options");
define("FORLAN_63", "Ranks");
define("FORLAN_64", "Enter your levels here, if left blank generic stars will be used to denote level. Separate levels with comma. Maximum of 10 levels, lowest first.");
define("FORLAN_65", "Forum Title");
define("FORLAN_66", "Poll plugin not installed");
define("FORLAN_67", "Posts to activate signature:");
define("FORLAN_68", "The number of posts needed to allow someone's signature to show on the forums. (0 means none)");
define("FORLAN_69", "Class whose signature is displayed in forums:");

define("FORLAN_70", "Enable file / image attachments");
define("FORLAN_71", "Allow users to upload file or image with their forum post,");
define("FORLAN_72", "Update Order");
define("FORLAN_73", "Order Updated");

define("FORLAN_75", "Parents");
define("FORLAN_76", "Forums Front Page");
define("FORLAN_77", "Create Forums");
define("FORLAN_78", "Forum Order");
define("FORLAN_79", "Preferences");
define("FORLAN_80", "Options");
define("FORLAN_81", "Are you sure you want to delete this parent? - forums of this parent will also be deleted");
define("FORLAN_82", "Are you sure you want to delete this forum?");
define("FORLAN_83", "Create Parents");
define("FORLAN_84", "Members Only");
define("FORLAN_85", "Read Only");
define("FORLAN_86", "Admin Only");
define("FORLAN_87", "Prune topics with no replies in this many days:");

define("FORLAN_88", "Prune topics with no replies in this many days:");

define("FORLAN_89", "Delete posts completely");
define("FORLAN_90", "Make posts inactive");

define("FORLAN_91", "post(s) made inactive");
define("FORLAN_92", "thread(s) deleted");
define("FORLAN_93", "reply (replies) deleted");

define("FORLAN_94", "Set Ranks");
define("FORLAN_95", "Ranks saved");
define("FORLAN_96", "Forum deleted");
define("FORLAN_97", "Parent deleted");

define("FORLAN_98", "Rank Name");
define("FORLAN_99", "number of points before level change");
define("FORLAN_100", "upload images to e107_themes/Your_Theme/forum/");
define("FORLAN_101", "Main Site Admin");
define("FORLAN_102", "Threshold");
define("FORLAN_103", "Site Admin");
define("FORLAN_104", "Rank Image");
define("FORLAN_105", "Forum Moderator");


define("FORLAN_106", "Prune Type:");
define("FORLAN_107", "Forum");
define("FORLAN_108", " deleted");
define("FORLAN_109", "days:");
define("FORLAN_110", "Prune");
define("FORLAN_111", "deactivate");

define("FORLAN_112", "Enable Redirect");
define("FORLAN_113", "Tick this to make browser redirect to forum page after replying");
define("FORLAN_114", "User Custom Title");
define("FORLAN_115", "Tick this to allow users to change their Custom Title");
define("FORLAN_116", "Reported Posts");
define("FORLAN_117", "This will delete the record of the reported post. Not the post itself.");
define("FORLAN_118", "Reported post deleted");
// define("FORLAN_119", "Clicking links will open forum in a new window.");
define("FORLAN_120", "Tick this to allow users to change their Custom Title");
define("FORLAN_121", "No reported posts");
define("FORLAN_122", "Click here to email admin when someone reports a forum post");
define("FORLAN_123", "Forum Rules");
define("WMGLAN_1", "Rules for Guests");
define("WMGLAN_2", "Rules for Members");
define("WMGLAN_3", "Rules for Administrators");
define("WMGLAN_4", "Submit");
define("WMGLAN_5", "Set Forum Rules");
define("WMGLAN_6", "Activate?");
define("FORLAN_126", "Show Tooltips");
define("FORLAN_127", "Tick here to show a tooltip containing the first post of the thread when mouse hovers over thread name. ");
define("FORLAN_128", "Length of tooltip");
define("FORLAN_129", "This will determine the number of characters to display in the tooltip. ");
define("FORLAN_130", "click here");
define("FORLAN_131", "to set max file size, allowed types etc");
define("FORLAN_132", "Emphasize Sticky Threads");
define("FORLAN_133", "Give extra emphasis to sticky threads (separate thread sections and headers)");
define("FORLAN_134", "Maximum width of uploaded image");
define("FORLAN_135", "Leave blank to disable auto resizing of images");
define("FORLAN_136", "Create link to full size image");
define("FORLAN_137", "Enabling this will resize larger images and also create a link to the original full size image. If disabled, original image will be discarded");
define("FORLAN_138", "Prune these forums");
define("FORLAN_139", "To use this setting you also need to tick 'Enable image posting' on the <a href='".e_ADMIN."image.php'>images</a> page");
define("FORLAN_140", "View");
define("FORLAN_141", "Post");
define("FORLAN_142", "Post permission");
define("FORLAN_143", "Indicates who can post to the forum");
define("FORLAN_144", "Moderators set");
define("FORLAN_145", "Configure sub-forums");
define("FORLAN_146", "No sub-forums yet");
define("FORLAN_147", "Update sub-forums");
define("FORLAN_148", "Create sub-forums");
define("FORLAN_149", "sub-forums");
define("FORLAN_150", "sub-forum");
define("FORLAN_151", "ID");
define("FORLAN_152", "posts");
define("FORLAN_153", "Tools");
define("FORLAN_154", "Reply Deleted");
define("FORLAN_155", "Forum Categories");

define("FORLAN_156", "Select forum(s) to perform action on");
define("FORLAN_157", "All Forums");
define("FORLAN_158", "Recalculate forum lastpost info");
define("FORLAN_159", "Select to recalculate lastpost info");
define("FORLAN_160", "Select to perform this on forums only, not threads");
define("FORLAN_161", "Recalculate post / reply counts");
define("FORLAN_162", "Select to recalculate forum thread/reply counts");
define("FORLAN_163", "Recalculate user forum posts counts");
define("FORLAN_164", "Select to recalculate user forum counts");
define("FORLAN_165", "Execute functions");
define("FORLAN_166", "Forum Tools");
define("FORLAN_167", "Counts updated for forum");
define("FORLAN_168", "Lastpost info updated for forum");
define("FORLAN_169", "User forum counts updated");
define("FORLAN_170", "Reports");
define("FORLAN_171", "Report on forum post");
define("FORLAN_172", "Delete This Report");
define("FORLAN_173", "Thread title");
define("FORLAN_174", "Reported by user");
define("FORLAN_175", "Report submitted");
define("FORLAN_176", "Report");

define("FORLAN_177", "email notification ON by default");
define("FORLAN_178", "Tick this to allow make the email notification checkbox be on by default");

define("FORLAN_179", "(Adding a * to the beginning of the forum name will make this forum a container for sub-forums only. The forum theme must support this option also.)");
define("FORLAN_180", "Confirm delete operation");
define("FORLAN_181", "Confirm Delete");
define("FORLAN_182", "also recalculate replies for all threads in selected forum");
define("FORLAN_183", "(this function is not allowed when selecting 'all forums' due to the number of queries it will generate)");

?>
